@@ -13,7 +13,7 @@
 # WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 # License for the specific language governing permissions and limitations
 # under the License.
-from mock import patch
+from unittest.mock import patch
 
 from designateclient.tests import v2
 from designateclient.v2 import zones
